@@ -12,8 +12,9 @@
 
 #define DBG_DBG 8
 #define DBG_INFO 16
-#define DBG_WARN 32
-#define DBG_ERR 64
+#define DBG_NOTICE 32
+#define DBG_WARN 64
+#define DBG_ERR 128
 
 void debug_init(char *ident);
 void debug_set_level(uint8_t level);
@@ -21,5 +22,11 @@ void debug_timestamp_on();
 uint8_t debug_get_level();
 void debug(uint8_t level, char *format, ...);
 void debugx(int status, uint8_t level, char *format, ...);
+void debugerrno(int err, uint8_t level, char *format, ...);
+void debugerrnox(int err, uint8_t level, char *format, ...);
 int debug_set_destination(char *dest);
 void debug_reopen_log();
+
+/* Local Variables: */
+/* c-file-style: "stroustrup" */
+/* End: */
